%bcond_with	dotlock

Name:           s-nail
Version:        14.9.25
Release:        %mkrel 2
Summary:        Environment for sending and receiving mail
Group:		Networking/Mail
# Everything is ISC except parts coming from the original Heirloom mailx which are BSD
License:        ISC and BSD with advertising and BSD
URL:            https://www.sdaoden.eu/code.html#s-nail
Source0:        https://www.sdaoden.eu/downloads/%{name}-%{version}.tar.xz
Source1:        https://www.sdaoden.eu/downloads/%{name}-%{version}.tar.xz.asc
# https://ftp.sdaoden.eu/steffen.asc
Source2:        steffen.asc
# From Fedora:
# https://bugzilla.redhat.com/show_bug.cgi?id=2171723
Patch0:         s-nail-makeflags.patch
Patch1:         s-nail-14.9.25-test-sha256.patch

BuildRequires:  gnupg2
BuildRequires:  openssl
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(ncurses)

# (mga#29626)
Obsoletes:	nail < 12.4-18
Provides:	nail = %{version}-%{release}
Provides:	mailx = %{version}-%{release}

%description
S-nail provides a simple and friendly environment for sending and receiving
mail. It is intended to provide the functionality of the POSIX mailx(1)
command, but is MIME capable and optionally offers extensions for line editing,
S/MIME, SMTP and POP3, among others. S-nail divides incoming mail into its
constituent messages and allows the user to deal with them in any order. It
offers many commands and internal variables for manipulating messages and
sending mail. It provides the user simple editing capabilities to ease the
composition of outgoing messages, and increasingly powerful and reliable
non-interactive scripting capabilities.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'

%autosetup -p1

cat <<EOF >>nail.rc

# %{_vendor}-specific defaults
set bsdcompat
set noemptystart
set prompt='& '
EOF

%build
%make_build \
    CFLAGS="%{build_cflags}" \
    LDFLAGS="%{build_ldflags}" \
    OPT_AUTOCC=no \
    OPT_DEBUG=yes \
    OPT_NOMEMDBG=yes \
    OPT_DOTLOCK=%{?with_dotlock:yes}%{!?with_dotlock:no} \
    VAL_PREFIX=%{_prefix} \
    VAL_SYSCONFDIR=%{_sysconfdir} \
    VAL_MAIL=%{_localstatedir}/mail \
    config

%make_build build

%install
%make_install

# s-nail binary is installed with 0555 permissions, fix that
chmod 0755 %{buildroot}%{_bindir}/%{name}

# symlinks
for i in Mail mail mailx nail; do
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/$i
ln -s %{name}.1.xz %{buildroot}%{_mandir}/man1/$i.1.xz
done

%check
make test

%files
%license COPYING
%doc NEWS README
%{_bindir}/Mail
%{_bindir}/mail
%{_bindir}/mailx
%{_bindir}/nail
%{_bindir}/%{name}
%if %{with dotlock}
%{_libexecdir}/s-nail-dotlock
%endif
%config(noreplace) %{_sysconfdir}/%{name}.rc
%{_mandir}/man1/Mail.1*
%{_mandir}/man1/mail.1*
%{_mandir}/man1/mailx.1*
%{_mandir}/man1/nail.1*
%{_mandir}/man1/%{name}.1*


%changelog
* Fri May 23 2025 daviddavid <daviddavid> 14.9.25-2.mga10
+ Revision: 2185987
- add fedora patches to fix build (thanks to Aurelian R)

* Sat Sep 28 2024 mrambo3501 <mrambo3501> 14.9.25-1.mga10
+ Revision: 2101905
- version 14.9.25

* Wed Nov 23 2022 pterjan <pterjan> 14.9.24-2.mga9
+ Revision: 1910546
- Fix build with make 4.4

* Fri Apr 08 2022 wally <wally> 14.9.24-1.mga9
+ Revision: 1848149
- new version 14.9.24

* Wed Mar 30 2022 umeabot <umeabot> 14.9.23-2.mga9
+ Revision: 1834273
- Mageia 9 Mass Rebuild

* Sat Nov 13 2021 wally <wally> 14.9.23-1.mga9
+ Revision: 1756088
- new version 14.9.23

* Sun Nov 07 2021 wally <wally> 14.9.22-7.mga9
+ Revision: 1754357
- import s-nail based on .spec from Fedora to replace nail (mga#29626)

